@@ -35,7 +35,11 @@ def prepForHistogram(data_array, num_digits = 0):
     
 ###############################################################################################################
 def plotHistogram(data_array, min_value, max_value, outlier, width, 
-                  figDetails = {'figsize': (7, 4), 'facecolor': "#5790fc", 'title': 'Histogram', 'xlabel': 'Seconds', 'ylabel': 'Frequency'}, num_digits = 0):
+                  figDetails = {'figsize': (7, 4), 
+                                'facecolor': "#5790fc", 
+                                'title': 'Histogram', 
+                                'xlabel': 'Seconds', 
+                                'ylabel': 'Frequency'}, num_digits = 0):
     # import packages
     import numpy as np
     import matplotlib.pyplot as plt
@@ -43,10 +47,12 @@ def plotHistogram(data_array, min_value, max_value, outlier, width,
     # create bins
     binSize = (max_value - min_value)/width # change this to another value if need be
     bins = []
-    for i in range(0, int(binSize + 1)):
-        bins = bins + [min_value + i*width]
+    for i in range(0, int(binSize)):
+        bins += [min_value + i*width]
     binTickLabels = [f'[{i},{i+width})' for i in bins]
-    binTickLabels[-1] = binTickLabels[-1].split(',')[0] + ',' + str(round(outlier)) + ')'
+    if outlier != False:
+        bins += [max_value + i*width]
+        binTickLabels += [f'[{max_value},{outlier})']
 
     # plot the figure
     y, x = np.histogram(data_array,bins=bins)
@@ -56,7 +62,7 @@ def plotHistogram(data_array, min_value, max_value, outlier, width,
     # create the figure
     # 7 inch the the width of a letter size paper excluding the margins
     fig, ax = plt.subplots(1,1, figsize = figDetails['figsize']) 
-    ax.bar(x, y, width = 0.8, align = 'center', facecolor = facecolor)
+    ax.bar(x, y, width = 0.8, align = 'center', facecolor = figDetails['facecolor'])
 
     # figure customization
     ax.set_title(figDetails['title'])
